@@ -1,6 +1,7 @@
 import os, sys
-sys.path.append('.')
-os.environ['DJANGO_SETTINGS_MODULE'] = 'settings'
+if 'DJANGO_SETTINGS_MODULE' not in os.environ:
+    sys.path.append('.')
+    os.environ['DJANGO_SETTINGS_MODULE'] = 'settings'
 from django.conf import settings
 from django.test.client import Client
 from django.test.utils import setup_test_environment, teardown_test_environment
@@ -20,7 +21,11 @@ def pytest_funcarg__django_client(request):
     old_name = settings.DATABASE_NAME
     def setup():
         setup_test_environment()
-        settings.DEBUG = False
+        if not hasattr(settings, 'DEBUG'):
+            settings.DEBUG = False
+        if 'south' in settings.INSTALLED_APPS:
+            from south.management.commands import patch_for_test_db_setup
+            patch_for_test_db_setup()
         from django.db import connection
         connection.creation.create_test_db(1, True)
         return Client()
